@@ -12,17 +12,16 @@
 #
 
 import abc
-import argparse
 import contextlib
 import logging
 import typing as ty
 
-import cliff.app
+from cliff import _argparse
 import openstack.exceptions
 from osc_lib.cli import parseractions
-from osc_lib.command import command
 from osc_lib import exceptions
 
+from openstackclient import command
 from openstackclient.i18n import _
 from openstackclient.network import utils
 
@@ -68,8 +67,6 @@ class NetDetectionMixin(metaclass=abc.ABCMeta):
     present the options for both network types, often qualified accordingly.
     """
 
-    app: cliff.app.App
-
     @property
     def _network_type(self):
         """Discover whether the running cloud is using neutron or nova-network.
@@ -84,7 +81,7 @@ class NetDetectionMixin(metaclass=abc.ABCMeta):
         # Have we set it up yet for this command?
         if not hasattr(self, '_net_type'):
             try:
-                if self.app.client_manager.is_network_endpoint_enabled():
+                if self.app.client_manager.is_network_endpoint_enabled():  # type: ignore
                     net_type = _NET_TYPE_NEUTRON
                 else:
                     net_type = _NET_TYPE_COMPUTE
@@ -136,7 +133,7 @@ class NetDetectionMixin(metaclass=abc.ABCMeta):
             )
         )
 
-    def get_parser(self, prog_name: str) -> argparse.ArgumentParser:
+    def get_parser(self, prog_name: str) -> _argparse.ArgumentParser:
         LOG.debug('get_parser(%s)', prog_name)
         parser = super().get_parser(prog_name)  # type: ignore
         parser = self.update_parser_common(parser)
@@ -163,11 +160,13 @@ class NetDetectionMixin(metaclass=abc.ABCMeta):
     def take_action(self, parsed_args):
         if self.is_neutron:
             return self.take_action_network(
-                self.app.client_manager.network, parsed_args
+                self.app.client_manager.network,  # type: ignore
+                parsed_args,
             )
         elif self.is_nova_network:
             return self.take_action_compute(
-                self.app.client_manager.compute, parsed_args
+                self.app.client_manager.compute,  # type: ignore
+                parsed_args,
             )
 
     def take_action_network(self, client, parsed_args):
@@ -203,6 +202,8 @@ class NetworkAndComputeDelete(NetworkAndComputeCommand, metaclass=abc.ABCMeta):
     following the rules in doc/source/command-errors.rst.
     """
 
+    resource: str
+
     def take_action(self, parsed_args):
         ret = 0
         resources = getattr(parsed_args, self.resource, [])
