@@ -19,9 +19,9 @@ import logging
 
 from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
-from osc_lib.command import command
 from osc_lib import utils
 
+from openstackclient import command
 from openstackclient.common import pagination
 from openstackclient.i18n import _
 
