@@ -26,11 +26,11 @@ from openstack import exceptions as sdk_exceptions
 from openstack import utils as sdk_utils
 from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
-from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.api import volume_v3
+from openstackclient import command
 from openstackclient.common import pagination
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -62,7 +62,7 @@ class KeyValueHintAction(argparse.Action):
             )
 
 
-class AttachmentsColumn(cliff_columns.FormattableColumn):
+class AttachmentsColumn(cliff_columns.FormattableColumn[list[ty.Any]]):
     """Formattable column for attachments column.
 
     Unlike the parent FormattableColumn class, the initializer of the
